%magicsquare
% The simplest of functions, with no inputs and outputs, generates a
% magic square and displays the sum of the rows and columns. An Excel sheet
% is also generated.
%
% Alternatively [M,C] = magicsquare(N) creates a NxN magic square 
% from the numbers 1 to N.
%
% Outputs are a magic square numeric array M, and a cell array C, which
% includes the row sums and column sums.
%
% LAST UPDATED by Andy French April 2016

function [M,C] = magicsquare(varargin)

%Check number of inputs
if nargin~=1
    %Define default number of columns of the magic square
    N = 6;
else
    N = varargin{1};
end

%

%Compute magic square (this calls the inbuilt MATLAB function magic)
M = magic(N);

%Sum both rows and columns
colsum = sum(M,1);
rowsum = sum(M,2);

%Construct a cell array with the elements of M and the sums
C = cell(N+2,N+2);
for n=1:N
    for m=1:N
        C{n,m} = num2str( M(n,m) );
    end
end

%Incorporate the row and column sums to cell array C
for n=1:N
    C{N+2,n} = num2str( colsum(n) );
    C{n,N+2} = num2str( rowsum(n) );
end

%Make the empty elements of C a blank string
for n=1:N
    C{N+1,n} = ' ';
    C{n,N+1} = ' ';
end
C{N+1,N+1} = ' ';
C{N+1,N+2} = ' ';
C{N+2,N+1} = ' ';
C{N+2,N+2} = ' ';

%Output an Excel sheet
xlswrite( ['Magic Square ',num2str(N),'.xls'] , C );

%End of code